import "dart:html";

class DaySection
{  
  final String color;
  final String timeStart;
  final String timeEnd;
  const DaySection(this.color, this.timeStart, this.timeEnd);
}


class Day
{
  Day(this._date)
  {
    _content = new DivElement();
  }
  
  void setContent(String title, List<DaySection> sections)
  {    
    _content.children.clear();    
    if (title == null) throw new ArgumentError.notNull("title");
    if (sections == null) throw new ArgumentError.notNull("sections");    
        
    _titleElement = new DivElement();
    _titleElement.innerHtml = title;
    
    DivElement timeAreaElement = new DivElement();
    timeAreaElement.style.height = "480px"; /// one hour is 30px our range is 06-22 (16 hours)
        
    sections.forEach((DaySection section)
    {      
      String day = _date.toIso8601String();
      day = day.substring(0, day.lastIndexOf("-") + 3);
      
      DateTime timeStart = _date.add(DateTime.parse(day + " " + section.timeStart).difference(_date));            
      DateTime timeEnd = _date.add(DateTime.parse(day + " " + section.timeEnd).difference(_date));
      
      int minutes = timeEnd.difference(timeStart).inMinutes;
      int sectionTop = (timeStart.difference(DateTime.parse(day + " 00:00")).inMinutes - 360) ~/ 2;
      int sectionHeight = (minutes) ~/ 2;
      
      DivElement sectionElement = new DivElement();
      sectionElement.style.position = "absolute";
      sectionElement.style.top = (sectionTop + 15).toString() + "px";
      sectionElement.style.width = "100%";
      sectionElement.style.display = "block";
      sectionElement.style.backgroundColor = section.color;
      sectionElement.style.height = sectionHeight.toString() + "px";      
      DivElement timeElement = new DivElement();      
      DivElement sectionTitleElement = new DivElement();      
      
      String timeStartString = timeStart.toIso8601String();
      String timeEndString = timeEnd.toIso8601String();
      int startIndex = timeStartString.indexOf("T") + 1;      
      timeStartString = timeStartString.substring(startIndex, startIndex + 5);      
      timeEndString = timeEndString.substring(startIndex, startIndex + 5);      
      
      timeElement.innerHtml = "$timeStartString - $timeEndString";
      timeElement.style.fontSize = "0.8em";
            
      //sectionElement.children.add(timeElement);
      sectionElement.children.add(sectionTitleElement);
      
      timeAreaElement.children.add(sectionElement);      
    });
    
    for (int i = 6; i < 22; i++)
    {
      DivElement t = new DivElement();
      t.innerHtml = (i < 10) ? "0" + i.toString() + ":00" : i.toString() + ":00";
      t.style.height = "30px";
      t.style.lineHeight = "90%";
      t.style.position = "relative";
      t.style.fontSize = "2.7em";
      t.style.opacity = "0.2";
      timeAreaElement.children.add(t);      
    }
    
    
    _content.children.add(_titleElement);
    _content.children.add(timeAreaElement);
  }  
  
  DivElement _titleElement;
  final DateTime _date;
  DivElement _content;
  DivElement get content => _content;
}
